@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2010-2012, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2010-2013, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <config.h>
@@ -26,7 +26,9 @@
 typedef struct {
   GtkWidget *win;
   GtkWidget *image;
-  GtkWidget *label;
+  GtkWidget *lname;
+  GtkWidget *lsize;
+  GtkWidget *lfile;
   GtkWidget *cat_list;
   GtkWidget *icon_list;
 
@@ -36,7 +38,7 @@ typedef struct {
 } IconBrowserData;
 
 static gboolean
-key_press_cb (GtkWidget *w, GdkEventKey *ev, gpointer data)
+key_press_cb (GtkWidget * w, GdkEventKey * ev, gpointer data)
 {
 #if GTK_CHECK_VERSION(2,24,0)
   if (ev->keyval == GDK_KEY_Escape)
@@ -51,7 +53,7 @@ key_press_cb (GtkWidget *w, GdkEventKey *ev, gpointer data)
 }
 
 static GtkListStore *
-load_icon_cat (IconBrowserData *data, gchar *cat)
+load_icon_cat (IconBrowserData * data, gchar * cat)
 {
   GtkListStore *store;
   GList *i, *icons;
@@ -68,26 +70,25 @@ load_icon_cat (IconBrowserData *data, gchar *cat)
       GtkTreeIter iter;
       GdkPixbuf *pb, *spb;
 
-      spb = pb = gtk_icon_theme_load_icon (data->theme, i->data, size,
-					   GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+      spb = pb = gtk_icon_theme_load_icon (data->theme, i->data, size, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
 
       if (pb)
-	{
-	  /* scale pixbuf if needed */
-	  w = gdk_pixbuf_get_width (pb);
-	  h = gdk_pixbuf_get_height (pb);
-	  if (w > size || h > size)
-	    {
-	      pb = gdk_pixbuf_scale_simple (spb, size, size, GDK_INTERP_BILINEAR);
-	      g_object_unref (spb);
-	    }
-	}
+        {
+          /* scale pixbuf if needed */
+          w = gdk_pixbuf_get_width (pb);
+          h = gdk_pixbuf_get_height (pb);
+          if (w > size || h > size)
+            {
+              pb = gdk_pixbuf_scale_simple (spb, size, size, GDK_INTERP_BILINEAR);
+              g_object_unref (spb);
+            }
+        }
 
       gtk_list_store_append (store, &iter);
       gtk_list_store_set (store, &iter, 0, pb, 1, i->data, -1);
 
       if (pb)
-	g_object_unref (pb);
+        g_object_unref (pb);
       g_free (i->data);
     }
   g_list_free (icons);
@@ -98,13 +99,13 @@ load_icon_cat (IconBrowserData *data, gchar *cat)
 }
 
 static void
-select_icon (GtkTreeSelection *sel, IconBrowserData *data)
+select_icon (GtkTreeSelection * sel, IconBrowserData * data)
 {
   GtkTreeModel *model;
   GtkTreeIter iter;
   GtkIconInfo *info;
   gint *sz, i;
-  gchar *icon, *file, *lbl;
+  gchar *icon, *file;
   GString *sizes;
 
   if (!gtk_tree_selection_get_selected (sel, &model, &iter))
@@ -128,26 +129,26 @@ select_icon (GtkTreeSelection *sel, IconBrowserData *data)
   while (sz[i])
     {
       if (sz[i] == -1)
-	g_string_append (sizes, _("scalable "));
+        g_string_append (sizes, _("scalable "));
       else
-	g_string_append_printf (sizes, "%dx%d ", sz[i], sz[i]);
+        g_string_append_printf (sizes, "%dx%d ", sz[i], sz[i]);
       i++;
     }
   /* free memory */
   g_free (sz);
 
-  lbl = g_strdup_printf (_("<b>Name:</b> %s\n<b>Sizes:</b> %s\n<b>Filename:</b> %s"),
-			 icon, sizes->str, file ? file : _("built-in"));
-  gtk_label_set_markup (GTK_LABEL (data->label), lbl);
+  gtk_label_set_text (GTK_LABEL (data->lname), icon);
+  gtk_label_set_text (GTK_LABEL (data->lsize), sizes->str);
+  gtk_label_set_text (GTK_LABEL (data->lfile), file ? file : _("built-in"));
+
   g_string_free (sizes, TRUE);
-  g_free (lbl);
 
   if (info)
     gtk_icon_info_free (info);
 }
 
 static void
-select_cat (GtkTreeSelection *sel, IconBrowserData *data)
+select_cat (GtkTreeSelection * sel, IconBrowserData * data)
 {
   GtkTreeModel *model;
   GtkListStore *store;
@@ -169,7 +170,7 @@ select_cat (GtkTreeSelection *sel, IconBrowserData *data)
 }
 
 gint
-main (gint argc, gchar *argv[])
+main (gint argc, gchar * argv[])
 {
   IconBrowserData *data;
   gchar **themes = NULL;
@@ -178,11 +179,11 @@ main (gint argc, gchar *argv[])
   GtkTreeSelection *sel;
   GtkTreeViewColumn *col;
   GtkCellRenderer *r;
-  GtkWidget *w, *p, *box;
+  GtkWidget *w, *p, *box, *t;
 
   GOptionEntry entrs[] = {
-    { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &themes, NULL, NULL },
-    { NULL }
+    {G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, &themes, NULL, NULL},
+    {NULL}
   };
 
   data = g_new0 (IconBrowserData, 1);
@@ -225,28 +226,89 @@ main (gint argc, gchar *argv[])
 
   /* create icon info box */
 #if !GTK_CHECK_VERSION(3,0,0)
-  w = gtk_hbox_new (FALSE, 5);
+  t = gtk_table_new (3, 3, FALSE);
+  gtk_table_set_col_spacings (GTK_TABLE (t), 5);
+  gtk_table_set_row_spacings (GTK_TABLE (t), 5);
 #else
-  w = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 5);
+  t = gtk_grid_new ();
+  gtk_grid_set_row_spacing (GTK_GRID (t), 5);
+  gtk_grid_set_column_spacing (GTK_GRID (t), 5);
 #endif
-  gtk_box_pack_start (GTK_BOX (box), w, FALSE, FALSE, 2);
-  data->image = gtk_image_new ();
-  gtk_box_pack_start (GTK_BOX (w), data->image, FALSE, FALSE, 2);
+  gtk_box_pack_start (GTK_BOX (box), t, FALSE, FALSE, 2);
 
-  data->label = gtk_label_new ("");
-  gtk_misc_set_alignment (GTK_MISC (data->label), 0, 0.5);
-  gtk_box_pack_start (GTK_BOX (w), data->label, TRUE, TRUE, 2);
+  data->image = gtk_image_new_from_stock ("gtk-missing-image", GTK_ICON_SIZE_DIALOG);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), data->image, 0, 1, 0, 3, GTK_FILL, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), data->image, 0, 0, 1, 3);
+#endif
+
+  w = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (w), _("<b>Name:</b>"));
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), w, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), w, 1, 0, 1, 1);
+#endif
+  data->lname = gtk_label_new (NULL);
+  gtk_label_set_selectable (GTK_LABEL (data->lname), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (data->lname), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), data->lname, 2, 3, 0, 1, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), data->lname, 2, 0, 1, 1);
+  gtk_widget_set_hexpand (data->lname, TRUE);
+#endif
+
+  w = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (w), _("<b>Sizes:</b>"));
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), w, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), w, 1, 1, 1, 1);
+#endif
+  data->lsize = gtk_label_new (NULL);
+  gtk_label_set_selectable (GTK_LABEL (data->lsize), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (data->lsize), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), data->lsize, 2, 3, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), data->lsize, 2, 1, 1, 1);
+  gtk_widget_set_hexpand (data->lsize, TRUE);
+#endif
+
+  w = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (w), _("<b>Filename:</b>"));
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), w, 1, 2, 2, 3, GTK_FILL, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), w, 1, 2, 1, 1);
+#endif
+  data->lfile = gtk_label_new (NULL);
+  gtk_label_set_selectable (GTK_LABEL (data->lfile), TRUE);
+  gtk_misc_set_alignment (GTK_MISC (data->lfile), 0, 0.5);
+#if !GTK_CHECK_VERSION(3,0,0)
+  gtk_table_attach (GTK_TABLE (t), data->lfile, 2, 3, 2, 3, GTK_FILL | GTK_EXPAND, 0, 0, 0);
+#else
+  gtk_grid_attach (GTK_GRID (t), data->lfile, 2, 2, 1, 1);
+  gtk_widget_set_hexpand (data->lfile, TRUE);
+#endif
 
   /* create icon browser */
+#if !GTK_CHECK_VERSION(3,0,0)
   p = gtk_hpaned_new ();
+#else
+  p = gtk_paned_new (GTK_ORIENTATION_HORIZONTAL);
+#endif
   gtk_paned_set_position (GTK_PANED (p), 150);
   gtk_box_pack_start (GTK_BOX (box), p, TRUE, TRUE, 2);
 
   /* create category list */
   w = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w),
-				  GTK_POLICY_AUTOMATIC,
-				  GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (w), GTK_SHADOW_ETCHED_IN);
   gtk_paned_add1 (GTK_PANED (p), w);
 
@@ -279,9 +341,7 @@ main (gint argc, gchar *argv[])
 
   /* create icons list */
   w = gtk_scrolled_window_new (NULL, NULL);
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w),
-				  GTK_POLICY_AUTOMATIC,
-				  GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (w), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (w), GTK_SHADOW_ETCHED_IN);
   gtk_paned_add2 (GTK_PANED (p), w);
 
