@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2012, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #ifndef _YAD_H_
@@ -22,16 +22,24 @@
 
 #include <config.h>
 
+#include <sys/types.h>
+#include <sys/ipc.h>
+
+#include <gdk/gdkx.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 
+#if GTK_CHECK_VERSION(3,0,0)
+#include <gtk/gtkx.h>
+#endif
+
 G_BEGIN_DECLS
 
 #define YAD_RESPONSE_OK         0
 #define YAD_RESPONSE_CANCEL     1
 #define YAD_RESPONSE_TIMEOUT   	70
-#define YAD_RESPONSE_ESC        -4  /* 252 */
-
+#define YAD_RESPONSE_ESC        -4      /* 252 */
 #define YAD_URL_REGEX "(http|https|ftp)://[a-zA-Z0-9./_%#&-]+"
 
 typedef enum {
@@ -46,6 +54,7 @@ typedef enum {
   YAD_MODE_ICONS,
   YAD_MODE_LIST,
   YAD_MODE_MULTI_PROGRESS,
+  YAD_MODE_NOTEBOOK,
   YAD_MODE_NOTIFICATION,
   YAD_MODE_PRINT,
   YAD_MODE_PROGRESS,
@@ -72,6 +81,7 @@ typedef enum {
   YAD_FIELD_FONT,
   YAD_FIELD_COLOR,
   YAD_FIELD_DATE,
+  YAD_FIELD_SCALE,
   YAD_FIELD_BUTTON,
   YAD_FIELD_LABEL,
   YAD_FIELD_TEXT,
@@ -82,8 +92,10 @@ typedef enum {
   YAD_COLUMN_NUM,
   YAD_COLUMN_FLOAT,
   YAD_COLUMN_CHECK,
+  YAD_COLUMN_RADIO,
   YAD_COLUMN_IMAGE,
   YAD_COLUMN_TOOLTIP,
+  YAD_COLUMN_HIDDEN,
   YAD_COLUMN_ATTR_FORE,
   YAD_COLUMN_ATTR_BACK,
   YAD_COLUMN_ATTR_FONT,
@@ -141,7 +153,7 @@ typedef struct {
   guint timeout;
   gchar *to_indicator;
   gchar *dialog_text;
-  gdouble text_align;
+  GtkJustification text_align;
   gchar *dialog_image;
   gboolean image_on_top;
   gchar *icon_theme;
@@ -155,6 +167,7 @@ typedef struct {
   gboolean no_markup;
   gboolean always_print;
   gboolean selectable_labels;
+  GtkButtonBoxStyle buttons_layout;
   /* window settings */
   gboolean sticky;
   gboolean fixed;
@@ -209,8 +222,8 @@ typedef struct {
 
 typedef struct {
   GSList *fields;
-  gdouble align;
   guint columns;
+  gboolean scroll;
 } YadFormData;
 
 typedef struct {
@@ -220,6 +233,7 @@ typedef struct {
   gboolean descend;
   gboolean sort_by_name;
   gboolean stdinput;
+  gboolean single_click;
   guint width;
   gchar *term;
 } YadIconsData;
@@ -228,6 +242,7 @@ typedef struct {
   GSList *columns;
   gboolean no_headers;
   gboolean checkbox;
+  gboolean radiobox;
   gboolean print_all;
   gint print_column;
   gint hide_column;
@@ -244,13 +259,18 @@ typedef struct {
 } YadMultiProgressData;
 
 typedef struct {
-  gboolean listen;
+  GSList *tabs;
+  guint borders;
+  key_t key;
+} YadNotebookData;
+
+typedef struct {
+  gboolean middle;
 } YadNotificationData;
 
 typedef struct {
   YadPrintType type;
   gboolean headers;
-  gboolean preview;
 } YadPrintData;
 
 typedef struct {
@@ -262,6 +282,10 @@ typedef struct {
 #endif
   guint percentage;
   gboolean rtl;
+  gchar *log;
+  gboolean log_expanded;
+  gboolean log_on_top;
+  gint log_height;
 } YadProgressData;
 
 typedef struct {
@@ -297,6 +321,10 @@ typedef struct {
   gboolean vertical;
   gchar *command;
   gchar *date_format;
+  gdouble align;
+  gboolean listen;
+  gboolean preview;
+  gboolean quoted_output;
 } YadCommonData;
 
 typedef struct {
@@ -315,6 +343,7 @@ typedef struct {
   YadIconsData icons_data;
   YadListData list_data;
   YadMultiProgressData multi_progress_data;
+  YadNotebookData notebook_data;
   YadNotificationData notification_data;
   YadPrintData print_data;
   YadProgressData progress_data;
@@ -324,8 +353,11 @@ typedef struct {
   gchar *rest_file;
   gchar **extra_data;
 
+  key_t plug;
+  guint tabnum;
+
 #ifndef G_OS_WIN32
-  gboolean kill_parent;
+  guint kill_parent;
   gboolean print_xid;
 #endif
 } YadOptions;
@@ -351,28 +383,43 @@ typedef struct {
   GdkPixbuf *big_fallback_image;
   GdkPixbuf *small_fallback_image;
   gchar *term;
+  guint max_tab;
 } YadSettings;
 
 extern YadSettings settings;
 
+typedef struct {
+  pid_t pid;
+  Window xid;
+} YadNTabs;
+
+/* pointer to shared memory for tabbed dialog */
+/* 0 item used for special info: */
+/*   pid - memory id */
+/*   xid - count of registered tabs (for sync) */
+extern YadNTabs *tabs;
+extern gint t_sem;
+
 void yad_options_init (void);
-GOptionContext * yad_create_context (void);
+GOptionContext *yad_create_context (void);
 void yad_set_mode (void);
 
-GtkWidget * calendar_create_widget (GtkWidget *dlg);
-GtkWidget * color_create_widget (GtkWidget *dlg);
-GtkWidget * entry_create_widget (GtkWidget *dlg);
-GtkWidget * file_create_widget (GtkWidget *dlg);
-GtkWidget * font_create_widget (GtkWidget *dlg);
-GtkWidget * form_create_widget (GtkWidget *dlg);
-GtkWidget * icons_create_widget (GtkWidget *dlg);
-GtkWidget * list_create_widget (GtkWidget *dlg);
-GtkWidget * multi_progress_create_widget (GtkWidget *dlg);
-GtkWidget * progress_create_widget (GtkWidget *dlg);
-GtkWidget * scale_create_widget (GtkWidget *dlg);
-GtkWidget * text_create_widget (GtkWidget *dlg);
+GtkWidget *calendar_create_widget (GtkWidget * dlg);
+GtkWidget *color_create_widget (GtkWidget * dlg);
+GtkWidget *entry_create_widget (GtkWidget * dlg);
+GtkWidget *file_create_widget (GtkWidget * dlg);
+GtkWidget *font_create_widget (GtkWidget * dlg);
+GtkWidget *form_create_widget (GtkWidget * dlg);
+GtkWidget *icons_create_widget (GtkWidget * dlg);
+GtkWidget *list_create_widget (GtkWidget * dlg);
+GtkWidget *multi_progress_create_widget (GtkWidget * dlg);
+GtkWidget *notebook_create_widget (GtkWidget * dlg);
+GtkWidget *progress_create_widget (GtkWidget * dlg);
+GtkWidget *scale_create_widget (GtkWidget * dlg);
+GtkWidget *text_create_widget (GtkWidget * dlg);
 
-void confirm_overwrite_cb (GtkDialog *dlg, gint id, gpointer data);
+void confirm_overwrite_cb (GtkDialog * dlg, gint id, gpointer data);
+void notebook_swallow_childs (void);
 
 void calendar_print_result (void);
 void color_print_result (void);
@@ -381,27 +428,37 @@ void file_print_result (void);
 void font_print_result (void);
 void form_print_result (void);
 void list_print_result (void);
+void notebook_print_result (void);
 void scale_print_result (void);
 void text_print_result (void);
 
-void dnd_init (GtkWidget *w);
+void dnd_init (GtkWidget * w);
 
 gint yad_notification_run (void);
 gint yad_print_run (void);
 gint yad_about (void);
 
+void notebook_close_childs (void);
+
 void read_settings (void);
 void write_settings (void);
 
-GdkPixbuf * get_pixbuf (gchar *name, YadIconSize size);
+GdkPixbuf *get_pixbuf (gchar * name, YadIconSize size);
 
-inline void strip_new_line (gchar *str);
-gchar **split_arg (const gchar *str);
+#ifdef __clang__
+extern inline void strip_new_line (gchar * str);
+#else
+inline void strip_new_line (gchar * str);
+#endif
+
+gchar **split_arg (const gchar * str);
 
 char *escape_markup (char *str);
 char *unescape_markup (char *str);
 char *escape_str (char *str);
 
+YadNTabs *get_tabs (key_t key, gboolean create);
+
 G_END_DECLS
 
 #endif /* _YAD_H_ */
